Index: /main/trunk/greenstone2/bin/script/export.pl
===================================================================
--- /main/trunk/greenstone2/bin/script/export.pl	(revision 21563)
+++ /main/trunk/greenstone2/bin/script/export.pl	(revision 21564)
@@ -712,5 +712,5 @@
     }
     else {
-	$export_info->save_revinfo_gdbm($expinfo_src_filename);
+	$export_info->save_revinfo_db($expinfo_src_filename);
     }
 
Index: /main/trunk/greenstone2/bin/script/import.pl
===================================================================
--- /main/trunk/greenstone2/bin/script/import.pl	(revision 21563)
+++ /main/trunk/greenstone2/bin/script/import.pl	(revision 21564)
@@ -692,5 +692,5 @@
     }
     else {
-	$archive_info->save_revinfo_gdbm($arcinfo_src_filename);
+	$archive_info->save_revinfo_db($arcinfo_src_filename);
     }
 
Index: /main/trunk/greenstone2/collect/demo/etc/collect.cfg
===================================================================
--- /main/trunk/greenstone2/collect/demo/etc/collect.cfg	(revision 21563)
+++ /main/trunk/greenstone2/collect/demo/etc/collect.cfg	(revision 21564)
@@ -4,4 +4,6 @@
 
 buildtype	mgpp
+
+infodbtype	gdbm
 
 indexes		text dls.Title,ex.Title dls.Subject dls.Organization dls.Keyword
@@ -22,4 +24,6 @@
 
 classify	List -metadata dls.Keyword -partition_type_within_level constant_size -buttonname Howto
+
+dynamic_classifier  Titles1  "dls.Title"
 
 format CL4VList "<td>[link][icon][/link]</td><td>[link][dls.Keyword][/link]"
Index: /main/trunk/greenstone2/perllib/ClassifyTreeModel.pm
===================================================================
--- /main/trunk/greenstone2/perllib/ClassifyTreeModel.pm	(revision 21563)
+++ /main/trunk/greenstone2/perllib/ClassifyTreeModel.pm	(revision 21564)
@@ -8,5 +8,5 @@
 #  *
 #  *  @param  $class       The name of the class to bless as a string
-#  *  @param  $collection  The name of the collection whose GDBM database we
+#  *  @param  $collection  The name of the collection whose info database we
 #  *                       will be accessing as a string
 #  *  @param  $root        The oid of the root node of the classifier as a
@@ -125,5 +125,5 @@
     if (&dbutil::read_infodb_entry("gdbm", $infodb_file_path, $clid) =~ /\w+/)
       {
-        # Since the CLID can directly reference the correct entry in the GDBM we
+        # Since the CLID can directly reference the correct entry in the info database we
         # just create the node and return it
         $result = new ClassifyTreeNode($self, $clid);
Index: /main/trunk/greenstone2/perllib/IncrementalDocument.pm
===================================================================
--- /main/trunk/greenstone2/perllib/IncrementalDocument.pm	(revision 21563)
+++ /main/trunk/greenstone2/perllib/IncrementalDocument.pm	(revision 21564)
@@ -2,5 +2,5 @@
 #
 # IncrementalDocument.pm -- An object to encapsulate the Greenstone 
-#                           document retrieved from the GDBM database.
+#                           document retrieved from the info database.
 #
 # A component of the Greenstone digital library software
@@ -48,5 +48,5 @@
     $self->{'collection'} = $collection;
 
-    # An associative array of information retrieved from the GDBM database
+    # An associative array of information retrieved from the info database
     # which maps a key string to a nested associative array listing values.
     $self->{'data'} = {};
@@ -147,5 +147,5 @@
     my ($self) = @_;
     #rint STDERR "IncrementalDocument::loadDocument()\n";
-    # Load the raw text for the document object from GDBM
+    # Load the raw text for the document object from the info database
     my $collection = $self->{'collection'};
     my $index_text_directory_path = &util::filename_cat($ENV{'GSDLHOME'}, "collect", $collection, "index", "text");
@@ -185,5 +185,5 @@
     my $text = $self->toString();
 
-    # Now store the object in the database using the GDBM utilities
+    # Now store the object in the info database
     my $collection = $self->{'collection'};
 
Index: /main/trunk/greenstone2/perllib/arcinfo.pm
===================================================================
--- /main/trunk/greenstone2/perllib/arcinfo.pm	(revision 21563)
+++ /main/trunk/greenstone2/perllib/arcinfo.pm	(revision 21564)
@@ -86,5 +86,5 @@
 }
 
-sub _load_info_gdbm
+sub _load_info_db
 {
     my $self = shift (@_);
@@ -118,10 +118,10 @@
 	}
 	else {
-	    $self->_load_info_gdbm($filename);
-	}
-    }
-}
-
-sub _load_filelist_gdbm
+	    $self->_load_info_db($filename);
+	}
+    }
+}
+
+sub _load_filelist_db
 {
     my $self = shift (@_);
@@ -151,5 +151,5 @@
 	}
 	else {
-	    $self->_load_filelist_gdbm($filename);
+	    $self->_load_filelist_db($filename);
 	}
     }
@@ -192,5 +192,5 @@
 }
 
-sub _save_info_gdbm {
+sub _save_info_db {
     my $self = shift (@_);
     my ($filename) = @_;
@@ -232,5 +232,5 @@
 }
 
-sub save_revinfo_gdbm {
+sub save_revinfo_db {
     my $self = shift (@_);
     my ($rev_filename) = @_;
@@ -258,5 +258,5 @@
     }
     else {
-	$self->_save_info_gdbm($filename);
+	$self->_save_info_db($filename);
     }
 }
Index: /main/trunk/greenstone2/perllib/cgiactions/baseaction.pm
===================================================================
--- /main/trunk/greenstone2/perllib/cgiactions/baseaction.pm	(revision 21563)
+++ /main/trunk/greenstone2/perllib/cgiactions/baseaction.pm	(revision 21564)
@@ -205,5 +205,5 @@
     my $users_db_file_path = &util::filename_cat($etc_directory, "users.db");
 
-    # Use db2txt instead of GDBM_File to get the user accounts information
+    # Use db2txt to get the user accounts information
     my $users_db_content = "";
     open(USERS_DB, "db2txt \"$users_db_file_path\" |");
Index: /main/trunk/greenstone2/perllib/cgiactions/metadataaction.pm
===================================================================
--- /main/trunk/greenstone2/perllib/cgiactions/metadataaction.pm	(revision 21563)
+++ /main/trunk/greenstone2/perllib/cgiactions/metadataaction.pm	(revision 21564)
@@ -119,6 +119,6 @@
     $collect_tail =~ s/^.*[\/|\\]//;
 
-    my $gdbm_directory = &util::filename_cat($collect_dir,$collect,"index","text");
-    my $gdbm_db = &util::filename_cat($gdbm_directory,"live-$collect_tail.gdb");
+    my $index_text_directory = &util::filename_cat($collect_dir,$collect,"index","text");
+    my $gdbm_db = &util::filename_cat($index_text_directory,"live-$collect_tail.gdb");
 
     my $cmd = "gdbmget $gdbm_db $dbkey";
@@ -179,6 +179,6 @@
     $collect_tail =~ s/^.*[\/\\]//;
 
-    my $gdbm_directory = &util::filename_cat($collect_dir,$collect,"index","text");
-    my $gdbm_db = &util::filename_cat($gdbm_directory,"$collect_tail.gdb");
+    my $index_text_directory = &util::filename_cat($collect_dir,$collect,"index","text");
+    my $gdbm_db = &util::filename_cat($index_text_directory,"$collect_tail.gdb");
 
     my $doc_rec_string = &dbutil::read_infodb_entry("gdbm", $gdbm_db, $docid);
@@ -239,6 +239,6 @@
     $collect_tail =~ s/^.*[\/\\]//;
 
-    my $gdbm_directory = &util::filename_cat($collect_dir,$collect,"index","text");
-    my $gdbm_db = &util::filename_cat($gdbm_directory,"live-$collect_tail.gdb");
+    my $index_text_directory = &util::filename_cat($collect_dir,$collect,"index","text");
+    my $gdbm_db = &util::filename_cat($index_text_directory,"live-$collect_tail.gdb");
 
     my $cmd = "gdbmset \"$gdbm_db\" \"$dbkey\" \"$metavalue\"";
@@ -296,6 +296,6 @@
     $collect_tail =~ s/^.*[\/\\]//;
 
-    my $gdbm_directory = &util::filename_cat($collect_dir,$collect,"index","text");
-    my $gdbm_db = &util::filename_cat($gdbm_directory,"$collect_tail.gdb");
+    my $index_text_directory = &util::filename_cat($collect_dir,$collect,"index","text");
+    my $gdbm_db = &util::filename_cat($index_text_directory,"$collect_tail.gdb");
 
     my $doc_rec_string = &dbutil::read_infodb_entry("gdbm", $gdbm_db, $docid);
@@ -755,6 +755,6 @@
     $collect_tail =~ s/^.*[\/\\]//;
 
-    my $gdbm_directory = &util::filename_cat($collect_dir,$collect,"index","text");
-    my $gdbm_db = &util::filename_cat($gdbm_directory,"live-$collect_tail.gdb");
+    my $index_text_directory = &util::filename_cat($collect_dir,$collect,"index","text");
+    my $gdbm_db = &util::filename_cat($index_text_directory,"live-$collect_tail.gdb");
 
     my $cmd = "gdbmdel \"$gdbm_db\" \"$dbkey\"";
@@ -811,6 +811,6 @@
     $collect_tail =~ s/^.*[\/\\]//;
 
-    my $gdbm_directory = &util::filename_cat($collect_dir,$collect,"index","text");
-    my $gdbm_db = &util::filename_cat($gdbm_directory,"$collect_tail.gdb");
+    my $index_text_directory = &util::filename_cat($collect_dir,$collect,"index","text");
+    my $gdbm_db = &util::filename_cat($index_text_directory,"$collect_tail.gdb");
 
     my $doc_rec_string = &dbutil::read_infodb_entry("gdbm", $gdbm_db, $docid);
Index: /main/trunk/greenstone2/perllib/classify.pm
===================================================================
--- /main/trunk/greenstone2/perllib/classify.pm	(revision 21563)
+++ /main/trunk/greenstone2/perllib/classify.pm	(revision 21564)
@@ -204,5 +204,5 @@
 	# but do want things like hastxt and archivedir
 	my @items = split /@/, $doc_db_hash->{$key};
-	# metadata is all from gdbm so should already be in utf8
+	# metadata is all from the info database so should already be in utf8
 	map {$doc_obj->add_utf8_metadata ($cursection, $key, $_); } @items;
 
@@ -214,9 +214,9 @@
 sub db_rec_to_hash {
     
-    my ($gdb_str_ref) = @_;
+    my ($infodb_str_ref) = @_;
 
     my $hashref = {};
 
-    my @entries = split(/\n/, $gdb_str_ref);
+    my @entries = split(/\n/, $infodb_str_ref);
     foreach my $entry (@entries) {
 	my($key, $value) = ($entry =~ /^<([^>]*)>(.*?)$/ );
Index: /main/trunk/greenstone2/perllib/inexport.pm
===================================================================
--- /main/trunk/greenstone2/perllib/inexport.pm	(revision 21563)
+++ /main/trunk/greenstone2/perllib/inexport.pm	(revision 21564)
@@ -304,5 +304,5 @@
     # record files marked for deletion in arcinfo
     foreach my $file (@$deleted_files) {
-	# use 'archiveinf-src' GDBM file to look up all the OIDs
+	# use 'archiveinf-src' info database file to look up all the OIDs
 	# that this file is used in (note in most cases, it's just one OID)
 	
Index: /main/trunk/greenstone2/perllib/plugin.pm
===================================================================
--- /main/trunk/greenstone2/perllib/plugin.pm	(revision 21563)
+++ /main/trunk/greenstone2/perllib/plugin.pm	(revision 21564)
@@ -228,5 +228,5 @@
 
     foreach my $file (@$deleted_files) {
-	# use 'archiveinf-src' GDBM file to look up all the OIDs
+	# use 'archiveinf-src' info database to look up all the OIDs
 	# that this file is used in (note in most cases, it's just one OID)
 	
Index: /main/trunk/greenstone2/perllib/plugins/ArchivesInfPlugin.pm
===================================================================
--- /main/trunk/greenstone2/perllib/plugins/ArchivesInfPlugin.pm	(revision 21563)
+++ /main/trunk/greenstone2/perllib/plugins/ArchivesInfPlugin.pm	(revision 21564)
@@ -24,6 +24,6 @@
 ###########################################################################
 
-# plugin which reads through an archives.inf (or GDBM equivalent,
-# archiveinf-doc.gdb file (i.e. the file generated in the
+# plugin which reads through an archives.inf (or info database equivalent,
+# archiveinf-doc.gdb file -- i.e. the file generated in the
 # archives directory when an import is done), processing each file it
 # finds
Index: /main/trunk/greenstone2/perllib/plugouts/BasePlugout.pm
===================================================================
--- /main/trunk/greenstone2/perllib/plugouts/BasePlugout.pm	(revision 21563)
+++ /main/trunk/greenstone2/perllib/plugouts/BasePlugout.pm	(revision 21564)
@@ -409,5 +409,5 @@
     ##############################
     $self->saveas($doc_obj,$doc_dir);
-    $self->archiveinf_gdbm($doc_obj,$doc_dir); 
+    $self->archiveinf_db($doc_obj,$doc_dir); 
 
 }
@@ -699,5 +699,5 @@
 }
 
-sub archiveinf_gdbm
+sub archiveinf_db
 {
     my $self = shift (@_);
@@ -740,8 +740,4 @@
     $self->archiveinf_files_to_field($doc_obj->get_meta_files(),"meta-file",
 				     $collect_dir,$oid_files);
-
-
-    # better not to commit to a particular db implementation, but
-    # for simplicity, will use GDBM for now.
 
     my $output_dir = $self->{'output_dir'};

Index: /main/trunk/greenstone2/perllib/IncrementalBuildUtils.pm
===================================================================
--- /main/trunk/greenstone2/perllib/IncrementalBuildUtils.pm	(revision 21563)
+++ /main/trunk/greenstone2/perllib/IncrementalBuildUtils.pm	(revision 21564)
@@ -31,6 +31,5 @@
 #  *               by John Rowe
 #  *  @version 2.0 Package version including seperation from calling code and
-#  *               modularisation by creating gdbmget, gdbmset and
-#  *               get_database_path by John Rowe
+#  *               modularisation by John Rowe
 #  *
 #  *  @author John Thompson, DL Consulting Ltd.
@@ -153,5 +152,5 @@
 #  *  1. The Lucene index must be updated. This will involve removing any
 #  *     existing value and, if required, adding a new value in its place.
-#  *  2. The GDBM database must be updated. Again any existing value will be
+#  *  2. The info database must be updated. Again any existing value will be
 #  *     removed and, if required, a new value added.
 #  *  3. Finally a check against the collect.cfg will be done to determine if
@@ -165,5 +164,5 @@
 #  *  A. Establish connection to Lucene
 #  *  B. Create a IncrementalDocument object for 'NT1' loading the information
-#  *     from the GDBM
+#  *     from the info database
 #  *  C. Check to see if this metadata is used to build a classifier(s) and if
 #  *     so create the appropriate ClassifyTreeModel(s)
@@ -177,6 +176,6 @@
 #  *     iii/ Call addDocument() in ClassifyTreeModel(s) as necessary
 #  *  F. Complete Lucene transaction
 #  *  G. Save IncrementalDocument to GDBM
 #  *  Note: ClassifyTreeModel automatically updates GDBM as necessary.
 #  *
 #  *  @param  $collection  The name of the collection to update as a string
@@ -202,5 +201,5 @@
     #    Lucene daemon.
     # B. Create a IncrementalDocument object for 'NT1' loading the information
-    #    from the GDBM
+    #    from the info database
     print STDERR "* creating incremental document for $oid\n" unless !$debug;
     my $doc_obj = new IncrementalDocument($collection, $oid);
@@ -232,5 +231,5 @@
     if (defined($old_value) && $old_value =~ /[\w\d]+/)
       {
-        print STDERR "* removing '$key'='$old_value' from GDBM database for document $oid\n" unless !$debug;
+        print STDERR "* removing '$key'='$old_value' from info database for document $oid\n" unless !$debug;
         # i/   Call ??? to remove key-value from Lucene index
         #      Moved elsewhere
@@ -247,5 +246,5 @@
     if (defined($new_value) && $new_value =~ /[\w\d]+/)
       {
-        print STDERR "* adding '$key'='$new_value' to GDBM database for document $oid\n" unless !$debug;
+        print STDERR "* adding '$key'='$new_value' to info database for document $oid\n" unless !$debug;
         # i/   Call ??? to add key-value from Lucene index
         #      Moved elsewhere
@@ -265,5 +264,5 @@
         &callGS2LuceneEditor($collection, $doc_obj->getDocNum, $key, $old_value, $new_value);
       }
     # G. Save IncrementalDocument to GDBM
     $doc_obj->saveDocument();
     $doc_obj = 0;
@@ -371,5 +370,5 @@
 # /** callGS2LuceneEditor() **/
 
 ## Remove a document from the GDBM and Index.
 #
 #  @param  collection  The collection to alter
@@ -388,6 +387,5 @@
     if ($doc_num > -1)
       {
         # Now use the GDBM utils to write a blank string to this oid in the
         # database
 	my $index_text_directory_path = &util::filename_cat($ENV{'GSDLHOME'}, "collect", $collection, "index", "text");
 	my $infodb_file_path = &dbutil::get_infodb_file_path("gdbm", $collection, $index_text_directory_path);
@@ -177,6 +176,6 @@
 #  *     iii/ Call addDocument() in ClassifyTreeModel(s) as necessary
 #  *  F. Complete Lucene transaction
-#  *  G. Save IncrementalDocument to GDBM
-#  *  Note: ClassifyTreeModel automatically updates GDBM as necessary.
+#  *  G. Save IncrementalDocument to info database
+#  *  Note: ClassifyTreeModel automatically updates the info database as necessary.
 #  *
 #  *  @param  $collection  The name of the collection to update as a string
@@ -265,5 +264,5 @@
         &callGS2LuceneEditor($collection, $doc_obj->getDocNum, $key, $old_value, $new_value);
       }
-    # G. Save IncrementalDocument to GDBM
+    # G. Save IncrementalDocument to info database
     $doc_obj->saveDocument();
     $doc_obj = 0;
@@ -371,5 +370,5 @@
 # /** callGS2LuceneEditor() **/
 
-## Remove a document from the GDBM and Index.
+## Remove a document from the info database and Index.
 #
 #  @param  collection  The collection to alter
@@ -388,6 +387,5 @@
     if ($doc_num > -1)
       {
-        # Now use the GDBM utils to write a blank string to this oid in the
-        # database
+        # Now write a blank string to this oid in the info database
 	my $index_text_directory_path = &util::filename_cat($ENV{'GSDLHOME'}, "collect", $collection, "index", "text");
 	my $infodb_file_path = &dbutil::get_infodb_file_path("gdbm", $collection, $index_text_directory_path);